pilas.actores.banana

Package pilas :: Package actores :: Module banana |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.banana

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  import pilas
    10  from pilas.actores import Actor
    11
    12
    13 -class Banana(Actor):
    14      """Muestra una banana que se combina (temáticamente) con el actor Mono.
    15
    16      .. image:: images/actores/banana.png
    17
    18
    19      Este actor se podría usar cómo alimento o bonus para otros
    20      actores.
    21
    22      Este actor tiene solo dos cuadros de animación que se pueden
    23      mostrar con los métodos ``abrir`` y ``cerrar``:
    24
    25          >>> banana = pilas.actores.Banana()
    26          >>> banana.abrir()
    27          >>> banana.cerrar()
    28
    29      """
    30
    31 -    def __init__(self, x=0, y=0):
    32          """ Constructor de la Banana.
    33
    34          :param x: Posición horizontal del Actor.
    35          :type x: int
    36          :param y: Posición vertical del Actor.
    37          :type y: int
    38          """
    39          Actor.__init__(self, x=x, y=y)
    40          self.imagen = pilas.imagenes.cargar_grilla("banana.png", 2)
    41          self.definir_cuadro(0)
    42
    43 -    def definir_cuadro(self, indice):
    44          """ Define el frame de la Banana a mostrar."""
    45          self.imagen.definir_cuadro(indice)
    46
    47 -    def abrir(self):
    48          """Muestra el gráfico de la banana abierta con menos cáscara."""
    49          self.definir_cuadro(1)
    50
    51 -    def cerrar(self):
    52          """Muestra el gráfico de banana normal (con cáscara)."""
    53          self.definir_cuadro(0)
    54